#!/usr/bin/env rexx
/* Controller.rex - Rexx Controller für Währungsumrechner */

currencyRates = .directory~new

::routine loadCurrencyRates public
    /* XML-Datei einlesen */
    xmlFile = "/mnt/data/Waehrungsumrechnungen.xml"
    call RxXmlLoadPackage 'RexxXML'

    /* XML-Datei parsen */
    xml = .RexxXMLDocument~new(xmlFile)
    rc = xml~open
    if rc <> 0 then do
        say "Fehler beim Einlesen der XML-Datei"
        return
    end

    /* Alle Umrechnungselemente abrufen */
    root = xml~documentElement
    umrechnungen = root~getElementsByTagName("Umrechnung")

    do i = 1 to umrechnungen~length
        umrechnung = umrechnungen~item(i-1)
        ausgangsWaehrung = umrechnung~getElementsByTagName("AusgangsWaehrung")~item(0)~textContent
        zielWaehrung = umrechnung~getElementsByTagName("ZielWaehrung")~item(0)~textContent
        kurs = umrechnung~getElementsByTagName("Kurs")~item(0)~textContent

        /* Schlüssel und Wert im Verzeichnis speichern */
        currencyRates[ausgangsWaehrung || ',' || zielWaehrung] = kurs
    end

    /* XML-Dokument schließen */
    call xml.close

/* Umrechnungskurse aus XML-Datei laden */
call loadCurrencyRates

-- Event-Handler für den Button-Klick
::routine buttonClicked public
    /* @get(idinputField ) */
    /* @get(idoutputField ) */
    /* @get(idcurrency1Menu i) */
    /* @get(idcurrency2Menu ) */

    -- Eingabewerte abrufen
    inputValue = idinputField~text
    fromCurrency = idcurrency1Menu~text
    toCurrency = idcurrency2Menu~text


    -- Umrechnungsrate abrufen
    exchangeRate = currencyRates[fromCurrency || ',' || toCurrency]


    -- Konvertierten Wert berechnen
    outputValue = inputValue * exchangeRate
    idoutputField~text = outputValue~format(0, 2)


-- Handler für die Auswahl im Währungsmenü 1
::routine handleCurrencyISelection public
    use arg menuItem
    currencyText = menuItem~text
    call setCurrency(1, currencyText)

-- Handler für die Auswahl im Währungsmenü 2
::routine handleCurrencyIISelection public
    use arg menuItem
    currencyText = menuItem~text
    call setCurrency(2, currencyText)

::routine setCurrency
    use arg menuId, currencyText

    select
        when menuId == 1 then do
            idcurrency1Menu~setText(currencyText)
        end
        when menuId == 2 then do
            idcurrency2Menu~setText(currencyText)
        end
        otherwise do
          say "Ungültige Menü-ID: " menuId
                  end
              end